class ChatbotWidget {
  constructor(botId, isTest) {
    this.botId = botId;
    this.isTest = isTest;
    this.apiBaseUrl = isTest
      ? "http://localhost:3000"
      : "https://www.mycheekybot.com";

    this.init();
  }

  async init() {
    if (window !== window.top) return; // Prevent iframe from loading in an unintended context
    console.log("Chatbot widget initialized on URL:", window.location.href);
    this.createPopupButton();
  }

  createPopupButton() {
    const button = document.getElementById("mcb-popup-button");
    if (button) {
      console.log("Popup button found, setting up click event");
      button.onclick = this.toggleChatWindow.bind(this); // Ensure it's bound to the instance
    } else {
      console.error("Popup button not found");
    }
  }

  toggleChatWindow() {
    const chatWindow = document.getElementById("chat-window");
    if (chatWindow) {
      // If the chat window exists, toggle visibility
      chatWindow.style.display =
        chatWindow.style.display === "none" || chatWindow.style.display === ""
          ? "block"
          : "none";
    } else {
      // If it does not exist, create it
      this.createChatWindow();
    }
  }

  createChatWindow() {
    const chatWindow = document.createElement("div");
    chatWindow.id = "chat-window";
    chatWindow.style.position = "fixed";
    chatWindow.style.bottom = "90px"; // Adjusted lower to be above the button
    chatWindow.style.right = "20px";
    chatWindow.style.width = "300px"; // Original value
    chatWindow.style.height = "400px"; // Original value
    chatWindow.style.backgroundColor = "#fff";
    chatWindow.style.border = "1px solid #ccc";
    chatWindow.style.boxShadow = "0 0 10px rgba(0,0,0,0.1)";
    chatWindow.style.display = "block"; // Set to visible after creation
    chatWindow.style.zIndex = "9999";
    chatWindow.style.overflow = "hidden"; // Prevent scrollbars on main widget window

    const chatHeader = document.createElement("div");
    chatHeader.style.backgroundColor = "#007bff"; // Header color
    chatHeader.style.color = "#ffffff"; // Text color
    chatHeader.style.padding = "6px"; // Padding for header
    chatHeader.style.display = "flex";
    chatHeader.style.justifyContent = "space-between";
    chatHeader.style.alignItems = "center";
    chatHeader.style.borderBottom = "1px solid #ccc"; // Border between header and body

    const headerText = document.createElement("span");
    headerText.innerText = "Chat with us!"; // Header text
    chatHeader.appendChild(headerText);

    const closeButton = document.createElement("button");
    closeButton.innerHTML = "&times;"; // Close icon
    closeButton.style.background = "none";
    closeButton.style.border = "none";
    closeButton.style.color = "#ffffff"; // Color of the close button
    closeButton.style.cursor = "pointer";
    closeButton.onclick = this.toggleChatWindow.bind(this); // Bind to this

    chatHeader.appendChild(closeButton);
    chatWindow.appendChild(chatHeader); // Add header to chat window

    // Chat body
    const chatBody = document.createElement("div");
    // chatBody.style.padding = "10px 10px 20px 10px"; // Padding for chat body
    chatBody.style.height = "calc(100% - 40px)"; // Calculated height based on header size
    // chatBody.style.overflowY = "auto"; // Allow vertical scrolling only within chat body

    // Create iframe
    const iframe = document.createElement("iframe");
    iframe.src = this.isTest
      ? `http://localhost:3000/chat/${this.botId}`
      : `https://www.mycheekybot.com/chat/${this.botId}`;
    iframe.style.width = "100%";
    iframe.style.height = "100%";
    iframe.style.border = "none";

    chatBody.appendChild(iframe);
    chatWindow.appendChild(chatBody);
    document.body.appendChild(chatWindow);
  }
}

// Bot initialization function
function botInitialization() {
  const popupTag = document.querySelector("div.mcb-popup[data-bot-id]");
  if (popupTag) {
    const botId = popupTag.getAttribute("data-bot-id");
    const isTest = popupTag.getAttribute("data-test") === "true";
    new ChatbotWidget(botId, isTest);
  }
}

document.addEventListener("DOMContentLoaded", botInitialization);
