<?php
/**
 * Plugin Name: My Cheeky Bot
 * Plugin URI: https://www.mycheekybot.com/wordpress
 * Description: Easily integrate your My Cheeky Bot assistant into your WordPress site.
 * Version: 0.0.1
 * Author: My Cheeky Bot Inc.
 * Author URI: https://www.mycheekybot.com
 * License: GPL2
 */

// Avoid direct access
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Enqueue scripts and styles
function mcb_enqueue_scripts() {
    wp_enqueue_style('mcb-style', plugin_dir_url(__FILE__) . 'assets/style.css');
    wp_enqueue_script('mcb-script', plugin_dir_url(__FILE__) . 'assets/mycheekybot.js', array(), null, true);
}
add_action('wp_enqueue_scripts', 'mcb_enqueue_scripts');

// Create shortcode for inline and popup widgets
function mcb_widget($atts) {
    $atts = shortcode_atts(array(
        'bot_id' => get_option('mcb_bot_id', ''),
        'div_id' => 'my-cheeky-bot-inline',
        'is_test' => 'false',
        'type' => 'inline',
    ), $atts);

    // Ensure bot_id is provided
    if (empty($atts['bot_id'])) {
        return '<div class="mcb-error-message" style="color: red; padding: 10px; border: 1px solid red;">
                    Error: The bot_id attribute is required. Please configure it properly.
                </div>';
    }

    // Return different structures based on the widget type
    switch ($atts['type']) {
        case 'popup':
            return '<div class="mcb-popup" data-bot-id="' . esc_attr($atts['bot_id']) . '">
                        <button id="mcb-popup-button" class="chatbot-launcher">
                            <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                                <path d="M12 22C17.5228 22 22 17.5228 22 12C22 6.47715 17.5228 2 12 2C6.47715 2 2 6.47715 2 12C2 16.714 2 19.071 3.46447 20.5355C4.92893 22 7.28595 22 12 22Z" fill="#007bff"/>
                                <path d="M9 12H15M9 15H15M9 9H15" stroke="white" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
                            </svg>
                        </button>
                    </div>';
        case 'inline':
        default:
            return '<div id="' . esc_attr($atts['div_id']) . '" data-bot-id="' . esc_attr($atts['bot_id']) . '" data-test="' . esc_attr($atts['is_test']) . '"></div>';
    }
}
add_shortcode('my_cheeky_bot_widget', 'mcb_widget');

// Create a settings page for the plugin
function mcb_plugin_menu() {
    add_options_page('My Cheeky Bot Settings', 'My Cheeky Bot', 'manage_options', 'my-cheeky-bot', 'mcb_settings_page');
}
add_action('admin_menu', 'mcb_plugin_menu');

function mcb_settings_page() {
    ?>
    <div class="wrap">
        <h1>My Cheeky Bot Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('mcb_options_group');
            do_settings_sections('mcb_options_group');

            // Bot ID input
            $bot_id = get_option('mcb_bot_id', '');
            echo '<label>Bot ID: <input type="text" name="mcb_bot_id" value="' . esc_attr($bot_id) . '" /></label><br/><br/>';

            // Popup widget enable/disable checkbox
            $popup_enabled = get_option('mcb_popup_enabled', '0'); // Default to 'off'
            echo '<label><input type="checkbox" name="mcb_popup_enabled" value="1" ' . checked(1, $popup_enabled, false) . '/> Enable Popup Widget Globally</label><br/><br/>';

            submit_button('Save Settings');
            ?>
        </form>
    </div>
    <?php
}

add_action('admin_init', function() {
    register_setting('mcb_options_group', 'mcb_bot_id');
    register_setting('mcb_options_group', 'mcb_popup_enabled'); // Register the new option
});

// Inject popup widget if enabled
function mcb_inject_popup_widget() {
    $popup_enabled = get_option('mcb_popup_enabled', '0');
    $bot_id = get_option('mcb_bot_id', '');

    if ($popup_enabled && !empty($bot_id)) {
        echo '<div class="mcb-popup" data-bot-id="' . esc_attr($bot_id) . '">
                <button id="mcb-popup-button" class="chatbot-launcher">
                    <svg width="24px" height="24px" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M12 22C17.5228 22 22 17.5228 22 12C22 6.47715 17.5228 2 12 2C6.47715 2 2 6.47715 2 12C2 13.5997 2.37562 15.1116 3.04346 16.4525C3.22094 16.8088 3.28001 17.2161 3.17712 17.6006L2.58151 19.8267C2.32295 20.793 3.20701 21.677 4.17335 21.4185L6.39939 20.8229C6.78393 20.72 7.19121 20.7791 7.54753 20.9565C8.88837 21.6244 10.4003 22 12 22Z" stroke="#ffffff" stroke-width="1.5"/>
                        <path opacity="0.5" d="M8 12H8.009M11.991 12H12M15.991 12H16" stroke="#ffffff" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"/>
                    </svg>
                </button>
              </div>';
    }
}
add_action('wp_footer', 'mcb_inject_popup_widget');